summaryrefslogtreecommitdiff
path: root/docs
diff options
context:
space:
mode:
authorMariusz Felisiak <felisiak.mariusz@gmail.com>2022-05-31 15:21:17 +0200
committerGitHub <noreply@github.com>2022-05-31 15:21:17 +0200
commitebf25555bbed3e9112d4b726575d60b242daf48a (patch)
treedff625864b0f0e5657ad319c6a663fc72e641c31 /docs
parentac90529cc58507d9a07610809a795ec5fc3cbf8c (diff)
Bumped minimum Sphinx version to 4.5.0.
Related Sphinx changes: - https://github.com/sphinx-doc/sphinx/pull/8898 - https://github.com/sphinx-doc/sphinx/issues/8326
Diffstat (limited to 'docs')
-rw-r--r--docs/conf.py18
1 files changed, 9 insertions, 9 deletions
diff --git a/docs/conf.py b/docs/conf.py
index bbb6776592..3e37509337 100644
--- a/docs/conf.py
+++ b/docs/conf.py
@@ -32,7 +32,7 @@ sys.path.append(abspath(join(dirname(__file__), "_ext")))
# -- General configuration -----------------------------------------------------
# If your documentation needs a minimal Sphinx version, state it here.
-needs_sphinx = "1.6.0"
+needs_sphinx = "4.5.0"
# Add any Sphinx extension module names here, as strings. They can be extensions
# coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
@@ -94,8 +94,8 @@ source_suffix = ".txt"
# The encoding of source files.
# source_encoding = 'utf-8-sig'
-# The master toctree document.
-master_doc = "contents"
+# The root toctree document.
+root_doc = "contents"
# General substitutions.
project = "Django"
@@ -127,12 +127,12 @@ else:
django_next_version = "4.2"
extlinks = {
- "bpo": ("https://bugs.python.org/issue?@action=redirect&bpo=%s", "bpo-"),
- "commit": ("https://github.com/django/django/commit/%s", ""),
- "cve": ("https://nvd.nist.gov/vuln/detail/CVE-%s", "CVE-"),
+ "bpo": ("https://bugs.python.org/issue?@action=redirect&bpo=%s", "bpo-%s"),
+ "commit": ("https://github.com/django/django/commit/%s", "%s"),
+ "cve": ("https://nvd.nist.gov/vuln/detail/CVE-%s", "CVE-%s"),
# A file or directory. GitHub redirects from blob to tree if needed.
- "source": ("https://github.com/django/django/blob/main/%s", ""),
- "ticket": ("https://code.djangoproject.com/ticket/%s", "#"),
+ "source": ("https://github.com/django/django/blob/main/%s", "%s"),
+ "ticket": ("https://code.djangoproject.com/ticket/%s", "#%s"),
}
# The language for content autogenerated by Sphinx. Refer to documentation
@@ -347,7 +347,7 @@ man_pages = [
# description, category, toctree_only)
texinfo_documents = [
(
- master_doc,
+ root_doc,
"django",
"",
"",